"""Initialize the app"""

# AA Skillfarm
from skillfarm.app_settings import SKILLFARM_APP_NAME

__version__ = "0.5.3"
__title__ = "Skillfarm"

USER_AGENT_TEXT = f"{SKILLFARM_APP_NAME} v{__version__}"
